@@ -7,6 +7,7 @@ from loguru import logger
 from pbt.config import PBTConfig
 from pbt.package.manager.poetry import Poetry
 from pbt.package.manager.maturin import Maturin
+from pbt.package.manager.python import PythonPkgManager
 from pbt.package.package import PackageType
 from pbt.package.pipeline import BTPipeline, VersionConsistent
 from pbt.package.registry.pypi import PyPI
@@ -17,10 +18,15 @@ def init(
     cwd: str, packages: List[str], verbose: bool
 ) -> Tuple[BTPipeline, PBTConfig, List[str]]:
     cfg = PBTConfig.from_dir(cwd)
-    managers: Dict[PackageType, PkgManager] = {}
-    managers[PackageType.Poetry] = Poetry(cfg, managers)
-    managers[PackageType.Maturin] = Maturin(cfg, managers)
-    pl = BTPipeline(cfg.cwd, managers=managers)
+    managers: Dict[PackageType, PkgManager] = {
+        PackageType.Poetry: Poetry(cfg),
+        PackageType.Maturin: Maturin(cfg),
+    }
+    for k, v in managers.items():
+        if isinstance(v, PythonPkgManager):
+            v.set_package_managers(managers)
+
+    pl = BTPipeline(cfg, managers=managers)
     pl.discover()
 
     if len(packages) == 0:
@@ -77,12 +83,6 @@ def list(dev: bool = False, cwd: str = ".", verbose: bool = False):
     is_flag=True,
     help="Whether to install dev-dependencies as well",
 )
-@click.option(
-    "-e",
-    "--editable",
-    is_flag=True,
-    help="Whether to install the package and its local dependencies in editable mode",
-)
 @click.option("--cwd", default=".", help="Override current working directory")
 @click.option(
     "-v",
@@ -93,14 +93,13 @@ def list(dev: bool = False, cwd: str = ".", verbose: bool = False):
 def install(
     package: List[str],
     dev: bool = False,
-    editable: bool = False,
     cwd: str = ".",
     verbose: bool = False,
 ):
     """Make package"""
     pl, cfg, pkgs = init(cwd, package, verbose)
     pl.enforce_version_consistency()
-    pl.install(sorted(pkgs), include_dev=dev, editable=editable)
+    pl.install(sorted(pkgs), include_dev=dev)
 
 
 @click.command()
@@ -180,15 +179,11 @@ def publish(package: List[str], cwd: str = ".", verbose: bool = False):
     is_flag=True,
     help="increase verbosity",
 )
-def create_setuppy(package: List[str], cwd: str = ".", verbose: bool = False):
-    """Create setup.py file of a python package"""
+def build(package: List[str], cwd: str = ".", verbose: bool = False):
+    """Build packages"""
     pl, cfg, pkgs = init(cwd, package, verbose)
-
     with build_cache():
         for pkg_name in pkgs:
             pkg = pl.pkgs[pkg_name]
             manager = pl.managers[pkg.type]
-            assert isinstance(
-                manager, Poetry
-            ), "Only create setup.py for Poetry packages"
-            manager.create_setup_py(pkg)
+            manager.build(pkg)
